import { formatTime } from "../../training/utils";
import { useEffect, useState, useRef } from "react";
import { Howl } from "howler";
import { describeArc } from "../utils";

interface ICountdown {
  seconds: number;
  totalPercent: number;
  exercisePercent: number;
}

const Countdown = ({ seconds, totalPercent, exercisePercent }: ICountdown) => {
  const [color, setColor] = useState("rgba(55,55,55,1)");
  const [intSeconds, setIntSeconds] = useState(0);

  useEffect(() => {
    setIntSeconds(Math.floor(seconds));
  }, [seconds]);

  const rosie = useRef(
    new Howl({
      src: ["/media/ROSIE.mp3"],
      sprite: {
        five: [10211, 10883 - 10211],
        four: [11292, 11873 - 11292],
        three: [12251, 12809 - 12251],
        two: [13208, 13930 - 13208],
        one: [14376, 14948 - 14376]
      }
    })
  );

  useEffect(() => {
    if (intSeconds <= 5) {
      fadeIn();
      setTimeout(fadeOut, 300);
    }
    if (rosie.current) {
      if (intSeconds === 5) rosie.current.play("five");
      else if (intSeconds === 4) rosie.current.play("four");
      else if (intSeconds === 3) rosie.current.play("three");
      else if (intSeconds === 2) rosie.current.play("two");
      else if (intSeconds === 1) rosie.current.play("one");
    }
  }, [intSeconds]);

  function fadeIn() {
    setColor("rgba(127,0,0,1)");
  }
  function fadeOut() {
    setColor("rgba(55,55,55,1)");
  }

  return (
    <div id="timer" style={{ color }}>
      <svg>
        <text
          textAnchor="middle"
          alignmentBaseline="central"
          y="185"
          x="150"
          fill={color}
        >
          {formatTime(intSeconds)}
        </text>
        <circle
          cx="150"
          cy="150"
          r="140"
          fill="none"
          stroke="#aa333344"
          strokeWidth="5"
        />
        <circle
          cx="150"
          cy="150"
          r="130"
          fill="none"
          stroke="#3333aa44"
          strokeWidth="5"
        />
        <path
          d={describeArc(150, 150, 140, 0, totalPercent * 360)}
          fill="none"
          stroke="#aa3333ff"
          strokeWidth="8"
        />
        <path
          d={describeArc(150, 150, 130, 0, exercisePercent * 360)}
          fill="none"
          stroke="#3333aaff"
          strokeWidth="8"
        />
      </svg>

      <style jsx>
        {`
          :global(#timer svg) {
            width: 300px;
            height: 300px;
            font-size: 100px;
            font-weight: 900;
            transition: color 300ms ease-out;
          }
        `}
      </style>
    </div>
  );
};

export default Countdown;
